@@ -12,6 +12,6 @@ armaGinv <- function(x, tol=NULL)
     {
         if (!is.matrix(x) || !is.numeric(x))
             stop("input must be a matrix")
-        out <- .Call("armaGinv", x ,tol)
+        out <- .Call("armaGinvCpp", x ,tol)
         return(out)
     }
