@@ -6,6 +6,7 @@
 #' @param pairedLM  a k x 2 matrix containing the indices (rownumbers) of the
 #' paired LM. E.g. the left column contains the lefthand landmarks, while the
 #' right side contains the corresponding right hand landmarks.
+#' @param ... additional arguments
 #' @note in case both landmarks of a bilateral pair are missing a message will be issued. As well if there are missing landmarks on the midsaggital plane are detected.
 #' @details the configurations are mirrored and the relabled version is matched onto the original using a thin-plate spline deformation. The missing landmark is now estimated using its bilateral counterpart. If one side is completely missing, the landmarks will be mirrored and aligned by the unilateral landmarks.
 #' @return a matrix or array with fixed missing bilateral landmarks.
@@ -32,22 +33,28 @@
 #' ## result is a bit off due to actual asymmetry
 #' }
 #' @export
-fixLMmirror <- function(x, pairedLM) UseMethod("fixLMmirror")
+fixLMmirror <- function(x, pairedLM,...) UseMethod("fixLMmirror")
 
 #' @rdname fixLMmirror
 #' @export
-fixLMmirror.array <- function(x,pairedLM) {
+fixLMmirror.array <- function(x,pairedLM,...) {
     n <- dim(x)[3]
     out <- x
     for (i in 1:n) {
-        out[,,i] <- fixLMmirror(x[,,i],pairedLM=pairedLM)
+        tmp <- suppressWarnings(suppressMessages(try(fixLMmirror(x[,,i],pairedLM=pairedLM),silent = TRUE)))
+        if (!inherits(tmp,"try-error"))
+            out[,,i] <- tmp
+        else
+            warning(paste0("missing landmark estimation failed for specimen No.",i,": ",tmp[1]))
+        
     }
+    
     return(out)
 }
 
 #' @rdname fixLMmirror
 #' @export
-fixLMmirror.matrix <- function(x,pairedLM) {
+fixLMmirror.matrix <- function(x,pairedLM,...) {
     mydata <- x
     m <- dim(x)[2]
     count <- 0
@@ -62,10 +69,10 @@ fixLMmirror.matrix <- function(x,pairedLM) {
             checklist[count] <- j
         }
     }
-    affected <- affectCol <- goodPaired <- NULL
+    affected <- affectCol <- goodPaired <- badPaired <- NULL
     for (i in 1:nrow(pairedLM)) {
         if (prod(is.na(x[pairedLM[i,],]))) {
-            warning(paste("paired landmarks",pairedLM[i,1], "and" ,pairedLM[i,2] , ": one landmark of each side must be present"))
+            message(paste("paired landmarks",pairedLM[i,1], "and" ,pairedLM[i,2] , ": one landmark of each side should be present"))
             unilatNA <- append(unilatNA,pairedLM[i,])
             
         }
@@ -75,6 +82,7 @@ fixLMmirror.matrix <- function(x,pairedLM) {
             checkCol <- as.logical(apply(checkPaired,1,prod))
             affectCol <- append(affectCol,which(!as.logical(checkCol)))
             goodPaired <- append(goodPaired,pairedLM[i,which(!as.logical(checkCol))])
+            badPaired <- append(badPaired,pairedLM[i,which(as.logical(checkCol))])
         }
     }
     if (is.null(affected)) {
@@ -83,7 +91,7 @@ fixLMmirror.matrix <- function(x,pairedLM) {
     }
    
     if (!prod(checklist %in% pairedLM)){
-        warning("missing landmarks are not bilateral")
+        message("missing landmarks are not bilateral")
         unilatNA <- append(unilatNA,checklist[which(! checklist %in% pairedLM)])
     }
     if (length(unilatNA))
@@ -92,18 +100,26 @@ fixLMmirror.matrix <- function(x,pairedLM) {
     xmir[c(pairedLM),] <- xmir[c(pairedLM[,2:1]),]##relabel landmarks
     xref <- xmir[-c(unilatNA,pairedLM[affected,]),]
     xtar <- x[-c(unilatNA,pairedLM[affected,]),]
-    if (prod(sort(goodPaired) == sort(pairedLM[,1])) || prod(sort(goodPaired) == sort(pairedLM[,2]))) {
-        message("one side completely missing: mirroring on midplane")
-        trans <- computeTransform(x[unilat,],xmir[unilat,])
-        xrot <- applyTransform(xmir,trans)
-        xout <- x
-        xout[pairedLM[,which(checkCol)],] <- xrot[pairedLM[,which(checkCol)],]
+    # print(badPaired)
+    if ( (length(badPaired) >= nrow(pairedLM)) && ((prod(pairedLM[,1] %in% badPaired) || prod(pairedLM[,2] %in% badPaired)))) {
+ #   if ( (prod(sort(badPaired) %in% sort(pairedLM[,1])) && !prod(sort(goodPaired) %in% sort(pairedLM[,2]))) || (prod(sort(goodPaired) %in% sort(pairedLM[,2])) && !prod(sort(goodPaired) %in% sort(pairedLM[,1])))) {
+            warning("one side completely missing: mirroring on midplane")
+            xrows <- rowSums(x[unilat,])
+            xbad <- which(as.logical(is.na(xrows) + is.nan(xrows)))
+            bad <- unique(c(xbad))
+            if ((length(unilat)-length(bad)) < 4)
+                stop("not enough unilateral landmarks to compute transform")
+            
+            trans <- computeTransform(x[unilat,],xmir[unilat,])
+            xrot <- applyTransform(xmir,trans)
+            xout <- x
+            xout[pairedLM[,which(checkCol)],] <- xrot[pairedLM[,which(checkCol)],]
         
     } else {
         xout <- tps3d(xmir,xref,xtar,threads=1)
         xout[goodPaired,] <- x[goodPaired,]
     }
-
+   
     return(xout)
 
 }
